What's new in iParrot 1.0.5?
===========================
Release Date: 2019-11-08

Release Feature:
* `parrot record` has the `-ae, --auto-extract` parameter added
* fix bugs on simple_assert and log-mode
* update readme

What's new in iParrot 1.0.5?
===========================
Release Date: 2019-10-30

Release Feature:
* record -s supports both har file and directory
* solve some problems about response format
* fix bugs
* update readme

What's new in iParrot 1.0.4?
===========================
Release Date: 2019-10-25

Release Feature:
* change replay -o, --output to -t, --target
* solve some problems about file encoding and content structure
* fix bugs

What's new in iParrot 1.0.3?
===========================
Release Date: 2019-10-24

Release Feature:
* update README
* remove python 2.7 support
* fix bugs

What's new in iParrot 1.0.2?
===========================
Release Date: 2019-09-29

Release Feature:
* update setup.py
* fix bugs

What's new in iParrot 1.0.0?
===========================
Release Date: 2019-09-27

Release Feature:
* Build automated test solution for http requests based on recording and playback
* For details, go to `README.md`
